@@ -72,7 +72,7 @@ class ResetLoadLeftOnTicketStatusChange(Hook):
                 # also reset load in that case, we don't want initial estimation
                 # to be taken into account
                 attrs['load'] = 0
-            forentity.set_attributes(**attrs)
+            forentity.cw_set(**attrs)
 
 
 class SetTicketLoadLeft(Hook):
@@ -119,7 +119,7 @@ class SetModificationDateAfterAddComment(Hook):
         entity = self._cw.entity_from_eid(self.eidto)
         while entity.e_schema == 'Comment':
             entity = entity.cw_adapt_to('ITree').root()
-        entity.set_attributes(modification_date=datetime.now())
+        entity.cw_set(modification_date=datetime.now())
 
 
 class TicketDoneInProgressHook(Hook):
