@@ -81,7 +81,7 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         # manager user, in dev project
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
-        self.assertUnorderedIterableEqual(self.pactions(req, rset),
+        self.assertCountEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -253,7 +253,7 @@ class ProjectTC(TrackerBaseTC):
         """ Add an icon to the project, check its new size and format. """
         # add an icon `tux.png` of size 200 x 232
         img = Binary.from_file(self.datapath('tux.png'))
-        self.cubicweb.set_attributes(icon=img)
+        self.cubicweb.cw_set(icon=img)
         self.commit()
         self.cubicweb.cw_clear_all_caches()
         # read the icon image, check its size and format
@@ -266,7 +266,7 @@ class ProjectTC(TrackerBaseTC):
         # add garbage
         img = Binary("I don't exist")
         with self.assertRaises(ValueError):
-            self.cubicweb.set_attributes(icon=img)
+            self.cubicweb.cw_set(icon=img)
         self.assertEqual(None, self.cubicweb.icon_format)
 
 
@@ -312,14 +312,14 @@ class TicketTC(TrackerBaseTC):
         self.assertEqual(len(t.reverse_interested_in), 1)
 
     def test_load_after_state_changed_deprecated(self):
-        self.t1.set_attributes(load=2)
+        self.t1.cw_set(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('deprecated')
         self.commit()
         self.t1.cw_attr_cache.pop('load', None)
         self.assertEqual(self.t1.load, 0)
 
     def test_load_after_state_changed_rejected(self):
-        self.t1.set_attributes(load=2)
+        self.t1.cw_set(load=2)
         self.t1.cw_adapt_to('IWorkflowable').change_state('rejected')
         self.commit()
         self.t1.cw_attr_cache.pop('load', None)
@@ -340,17 +340,17 @@ class TicketTC(TrackerBaseTC):
 
     def test_modification_date_after_comment_added(self):
         olddate = datetime.today() - ONEDAY
-        self.t1.set_attributes(modification_date=olddate)
+        self.t1.cw_set(modification_date=olddate)
         ceid = self.execute('INSERT Comment C: C content "A commment", C comments X '
                             'WHERE X eid %(x)s', {'x': self.t1.eid})[0][0]
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
-        self.t1.set_attributes(modification_date=olddate)
+        self.t1.cw_set(modification_date=olddate)
         ceid2 = self.execute('INSERT Comment C: C content "A commment", C comments X '
                              'WHERE X eid %(x)s', {'x': ceid})[0][0]
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
-        self.t1.set_attributes(modification_date=olddate)
+        self.t1.cw_set(modification_date=olddate)
         self.execute('INSERT Comment C: C content "A commment", C comments X '
                      'WHERE X eid %(x)s', {'x': ceid2})
         self.commit()
@@ -363,7 +363,7 @@ class TicketTC(TrackerBaseTC):
         card = self.execute('INSERT Card X: X title "Manaul", P documented_by X'
                             '   WHERE P is Project').get_entity(0, 0)
         olddate = datetime.today() - ONEDAY
-        card.set_attributes(modification_date=olddate)
+        card.cw_set(modification_date=olddate)
         self.execute('INSERT Comment C: C content "Typo included", '
                      '  C comments X WHERE X eid %(x)s', {'x': card.eid})
         self.commit()
@@ -375,7 +375,7 @@ class TicketTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Ticket')
         _ticket = rset.get_entity(0, 0)
         teid = rset[0][0]
-        self.assertUnorderedIterableEqual(self.pactions(req, rset),
+        self.assertCountEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -506,7 +506,7 @@ class TicketTC(TrackerBaseTC):
     def test_state_change_on_version_publishing(self):
         v2 = self.execute('INSERT Version V: V num "0.0.1", V version_of P '
                           'WHERE P is Project').get_entity(0, 0)
-        self.t1.set_relations(done_in=v2)
+        self.t1.cw_set(done_in=v2)
         self.commit()
         t1iwf = self.t1.cw_adapt_to('IWorkflowable')
         t1iwf.fire_transition('done')
@@ -529,7 +529,7 @@ class TicketTC(TrackerBaseTC):
                               u'developer')
         self.create_user(self.session, 'prj1client', groups=('users', 'cubicwebdevelopers'))
         self.commit()
-        self.t1.set_relations(done_in=self.v)
+        self.t1.cw_set(done_in=self.v)
         # -  change ticket status
         t1iwf= self.t1.cw_adapt_to('IWorkflowable')
         t1iwf.fire_transition('done')
