@@ -9,8 +9,11 @@ _ = unicode
 
 from cubicweb.predicates import is_instance
 from cubicweb.web import uicfg, facet
+from cubicweb.web.views import schema
 from cubicweb.web.views.urlrewrite import SchemaBasedRewriter, rgx, build_rset
 
+schema.SKIP_TYPES.add('see_also')
+schema.ALWAYS_SKIP_TYPES.add('see_also')
 
 class ForgeURLRewriter(SchemaBasedRewriter):
     """handle path with the form::
